// LICENSE : MIT
"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

function _defaults(obj, defaults) { var keys = Object.getOwnPropertyNames(defaults); for (var i = 0; i < keys.length; i++) { var key = keys[i]; var value = Object.getOwnPropertyDescriptor(defaults, key); if (value && value.configurable && obj[key] === undefined) { Object.defineProperty(obj, key, value); } } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : _defaults(subClass, superClass); }

var EventEmitter = require("events");
var eventType = "CHANGE";

var LogQueue = function (_EventEmitter) {
    _inherits(LogQueue, _EventEmitter);

    function LogQueue() {
        _classCallCheck(this, LogQueue);

        var _this = _possibleConstructorReturn(this, _EventEmitter.call(this));

        _this._logs = [];
        return _this;
    }

    /**
     * listen on change event and return un listen function
     * @param {function()}changeHandler
     * @returns {function()}
     */


    LogQueue.prototype.onChange = function onChange(changeHandler) {
        var _this2 = this;

        this.on(eventType, changeHandler);
        return function () {
            _this2.removeListener(eventType, changeHandler);
        };
    };

    /**
     * consume logs
     * purge log queue. please use careful
     * @returns {Array.<*>}
     */


    LogQueue.prototype.consumeLogs = function consumeLogs() {
        var chunks = this._logs.slice();
        this.clear();
        return chunks;
    };

    LogQueue.prototype.addLog = function addLog(chunk) {
        if (chunk == undefined) {
            return;
        }
        this._logs.push(chunk);
        this.emit(eventType);
    };

    LogQueue.prototype.clear = function clear() {
        this._logs.length = 0;
    };

    return LogQueue;
}(EventEmitter);

exports.default = LogQueue;
//# sourceMappingURL=LogQueue.js.map